@@ -174,6 +174,10 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// Start clean.
 	m_iUpdate = 0;
 
+	// Replicate the stacked/pages
+	for (int iTab = 0; iTab < m_ui.StackedWidget->count(); ++iTab)
+		m_ui.TabBar->addTab(m_ui.StackedWidget->widget(iTab)->windowTitle());
+
 	// Swappable params A/B group.
 	QButtonGroup *pSwapParamsGroup = new QButtonGroup(this);
 	pSwapParamsGroup->addButton(m_ui.SwapParamsAButton);
@@ -756,6 +760,9 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 		SIGNAL(toggled(bool)),
 		SLOT(swapParams(bool)));
 
+	// Direct stacked-page signal/slot
+	QObject::connect(m_ui.TabBar, SIGNAL(currentChanged(int)),
+		m_ui.StackedWidget, SLOT(setCurrentIndex(int)));
 
 	// Menu actions
 	QObject::connect(m_ui.helpAboutAction,
@@ -765,9 +772,11 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 		SIGNAL(triggered(bool)),
 		SLOT(helpAboutQt()));
 
-
 	// Epilog.
-	QWidget::adjustSize();
+	// QWidget::adjustSize();
+
+	m_ui.StatusBar->showMessage(tr("Ready"), 5000);
+	m_ui.StatusBar->setModified(false);
 }
 
 
@@ -814,8 +823,14 @@ void synthv1widget::paramChanged ( float fValue )
 		return;
 
 	synthv1widget_knob *pKnob = qobject_cast<synthv1widget_knob *> (sender());
-	if (pKnob)
+	if (pKnob) {
 		updateParam(m_knobParams.value(pKnob), fValue);
+		m_ui.StatusBar->showMessage(QString("%1 / %2: %3")
+			.arg(m_ui.StackedWidget->currentWidget()->windowTitle())
+			.arg(pKnob->toolTip())
+			.arg(pKnob->valueText()), 5000);
+		m_ui.StatusBar->setModified(true);
+	}
 
 	m_ui.Preset->dirtyPreset();
 }
@@ -836,6 +851,9 @@ void synthv1widget::resetParams (void)
 		updateParam(index, fValue);
 		m_params_ab[index] = fValue;
 	}
+
+	m_ui.StatusBar->showMessage(tr("Reset preset"), 5000);
+	m_ui.StatusBar->setModified(false);
 }
 
 
@@ -863,6 +881,10 @@ void synthv1widget::swapParams ( bool bOn )
 	}
 
 	m_ui.Preset->dirtyPreset();
+
+	const bool bSwapA = m_ui.SwapParamsAButton->isChecked();
+	m_ui.StatusBar->showMessage(tr("Swap %1").arg(bSwapA ? 'A' : 'B'), 5000);
+	m_ui.StatusBar->setModified(true);
 }
 
 
@@ -909,6 +931,13 @@ void synthv1widget::initPreset (void)
 
 
 // Preset clear.
+void synthv1widget::clearPreset (void)
+{
+	m_ui.Preset->clearPreset();
+}
+
+
+// Preset renewal.
 void synthv1widget::newPreset (void)
 {
 #ifdef CONFIG_DEBUG
@@ -917,6 +946,9 @@ void synthv1widget::newPreset (void)
 
 	resetParamKnobs();
 	resetParamValues();
+
+	m_ui.StatusBar->showMessage(tr("New preset"), 5000);
+	m_ui.StatusBar->setModified(false);
 }
 
 
@@ -981,7 +1013,11 @@ void synthv1widget::loadPreset ( const QString& sFilename )
 
 	file.close();
 
-	m_ui.Preset->setPreset(fi.completeBaseName());
+	const QString& sPreset = fi.completeBaseName();
+	m_ui.Preset->setPreset(sPreset);
+
+	m_ui.StatusBar->showMessage(tr("Load preset: %1").arg(sPreset), 5000);
+	m_ui.StatusBar->setModified(false);
 
 	QDir::setCurrent(currentDir.absolutePath());
 }
@@ -992,9 +1028,11 @@ void synthv1widget::savePreset ( const QString& sFilename )
 #ifdef CONFIG_DEBUG
 	qDebug("synthv1widget::savePreset(\"%s\")", sFilename.toUtf8().constData());
 #endif
+	const QString& sPreset = QFileInfo(sFilename).completeBaseName();
+
 	QDomDocument doc(SYNTHV1_TITLE);
 	QDomElement ePreset = doc.createElement("preset");
-	ePreset.setAttribute("name", QFileInfo(sFilename).completeBaseName());
+	ePreset.setAttribute("name", sPreset);
 	ePreset.setAttribute("version", SYNTHV1_VERSION);
 
 	QDomElement eParams = doc.createElement("params");
@@ -1014,6 +1052,9 @@ void synthv1widget::savePreset ( const QString& sFilename )
 		QTextStream(&file) << doc.toString();
 		file.close();
 	}
+
+	m_ui.StatusBar->showMessage(tr("Save preset: %1").arg(sPreset), 5000);
+	m_ui.StatusBar->setModified(false);
 }
 
 
