@@ -52,6 +52,11 @@ public:
 	void setParamKnob(synthv1::ParamIndex index, synthv1widget_knob *pKnob);
 	synthv1widget_knob *paramKnob(synthv1::ParamIndex index) const;
 
+	// Preset init.
+	void initPreset();
+	// Preset clear.
+	void clearPreset();
+
 	// Dirty close prompt,
 	bool queryClose();
 
@@ -63,7 +68,7 @@ public slots:
 
 protected slots:
 
-	// Preset clear.
+	// Preset renewal.
 	void newPreset();
 
 	// Param knob (widget) slots.
@@ -81,9 +86,6 @@ protected slots:
 
 protected:
 
-	// Preset init.
-	void initPreset();
-
 	// Reset swap params A/B group.
 	void resetSwapParams();
 
